function OnGetNewName(getNewNameData)
{
	// If the newname_field is empty, use this script to generate a new name.
	if (getNewNameData.newname_field == "") {
		var generateNamesUsingRules = true;
	}
	// In case it is not empty, do not make changes if the file name is not going to change.
	else if (getNewNameData.newname == getNewNameData.item.name) {
		return;
	}
	
	// Set the base directories and the filter for additional files to move.
	// Per file type group.
	var rules = {
		'Movies' : {
		baseDir: "C:\\Test\\Movies",
		stickyBaseDirList: [
			"E:\\ABC", 
			"E:\\ABC"
			],
		moveTogetherFilterLister: [
			".vtx", 
			".jpg", 
			"..\\Picture", 
			"..\\License"
			],
		},
		'Music' : {
		baseDir: "C:\\Test\\Music",
		stickyBaseDirList: [
			"E:\\XYZ", 
			],
		moveTogetherFilterLister: [
			".jpg", 
			"..\\License",
			"..\\Scan"
			],
		}
	}

	// -------- New Name

	// If needed, generate the new name.
	if (generateNamesUsingRules) {
	}

	// -------- Base Directory
	
	// Default is to not append an absolute directory if the file does not match a rule.
	var absoluteNewName = false;

	// Try to match a rule
	for (var rule in rules) {
		if (isFromGroup(getNewNameData.item, rule)) {
			// Match found! Save rule for later processing.
			var matchedRule = rules[rule];
			
			// Set absolute base directory path.
			var absoluteBaseDir = matchedRule.baseDir;
			
			// Determine if sticky base directory applies.
			for (var i = 0; i < matchedRule.stickyBaseDirList.length; i++) {
				if (String(getNewNameData.item.path).substring(0, matchedRule.stickyBaseDirList[i].length) === matchedRule.stickyBaseDirList[i]) {
					absoluteBaseDir = matchedRule.stickyBaseDirList[i];
					break;
				}
			}
			
			// Set final absolute path.
			absoluteNewName = absoluteBaseDir + "\\" + getNewNameData.newname;

			// Skip further processing related to the path.
			break;
		}
	}
	
	// -------- Additional Items

	// Only if the file to be renamed matched a rule previously.
	if (matchedRule) {
		// Compute how many levels are affected by the rule.
		
		// Level 0 refers to the same level as the item being renamed, level 1 to its parent, and so on.
		// Default is -1 for when there are no rules to move additional items.
		var maxLevel = -1;

		// Temporary variable.
		var moveFilter;

		// Compute maxLevel.
		for (var i = 0; i < matchedRule.moveTogetherFilterLister.length; i++) {
			moveFilter = matchedRule.moveTogetherFilterLister[i];
			filterLevelCount = moveFilter.split("..").length - 1;
			if (maxLevel < filterLevelCount) {
				maxLevel = filterLevelCount;
			}
		}

		// Process each level, if any.
		if (maxLevel >= 0) {
			// Variables to track the path to the current level.
			oldFolderEnumPath = getNewNameData.item.realpath;
			newFolderEnumPath = DOpus.FSUtil.NewPath(absoluteNewName);
			
			// Temporary variables.
			var moveFilterFolderName, folderItem, folderEnum;

			// Iterate over levels.
			for (var currentLevel = 0; currentLevel <= maxLevel; currentLevel++) {
				// Set paths to current level.
				oldFolderEnumPath.Parent;
				newFolderEnumPath.Parent;
				
				// Iterate over old items on current level and try to match them.
				folderEnum = DOpus.FSUtil.ReadDir(oldFolderEnumPath, false);
				while (!folderEnum.complete) {
					folderItem = folderEnum.Next;
					
					// Compare enumerated item to the names on the filter list.
					for (var i = 0; i < matchedRule.moveTogetherFilterLister.length; i++) {
						moveFilter = matchedRule.moveTogetherFilterLister[i];

						// If the filter is not at this level, skip it.
						filterLevelCount = moveFilter.split("..").length - 1;
						if (currentLevel < filterLevelCount) {
							break;
						}

						// If directory, check that its name matches.
						if (folderItem.is_dir) {
							var match = moveFilter.match(/.*\\(.*)/);
							if (match != null) {
								moveFilterFolderName = match[1];
							}
							if (folderItem.name == moveFilterFolderName) {
								moveAdditionalItem(folderItem, newFolderEnumPath);
							}
						} else {
							// If not, check that its extension matches.
							if (folderItem.ext == moveFilter) {
								moveAdditionalItem(folderItem, newFolderEnumPath);
							}
						}
					}
				}
			}
		}
	}
	
	return absoluteNewName;

	// Helper Function
	// Move files.
	function moveAdditionalItem(itemToMove, destinationPath) {
		moveDestination = DOpus.FSUtil.NewPath(destinationPath);
		moveDestination.Add(itemToMove.name);
		// To be replaced with actual move functionality.
		print("Move \"" + folderItem.name + "\" to \"" + moveDestination + "\"" );
		return;
	}
	
	// Helper Function
	// Return true if 'item' is from file type group 'needle'.
	function isFromGroup(item, needle) {
		if (item.groups.length) {
			for (var i=0; i < item.groups.length; i++)
			{
				if (item.groups(i).display_name === needle) return true;
			}
		}
		return false;
	}
	
	// Helper Function
	// Print only if requested.
	function print(text) {
		if (true) {
			DOpus.Output(text);
		}
	}
	
	// Helper Function
	// Display error message.
	function error(text) {
		DOpus.Output(text, true);
	}
}